import { PathPredicate } from './iterateSources';
import { BabelPlugin, RawBabelPlugin } from './TransformRunner';
export declare const DEFAULT_EXTENSIONS: Set<string>;
export declare type ParseOptionsResult = Options | Error;
export declare class Plugin {
    readonly rawPlugin: RawBabelPlugin;
    readonly inferredName: string;
    readonly path: string | undefined;
    readonly resolvedPath: string | undefined;
    readonly declaredName?: string;
    constructor(rawPlugin: RawBabelPlugin, inferredName: string, path?: string | undefined, resolvedPath?: string | undefined);
    static load(path: string, inferredName: string): Plugin;
}
export declare class DeferredPlugin {
    readonly path: string;
    readonly inferredName: string;
    private loaded?;
    constructor(path: string, inferredName: string);
    load(): Plugin;
}
export default class Options {
    readonly sourcePaths: Array<string>;
    readonly plugins: Array<DeferredPlugin>;
    readonly pluginOptions: Map<string, object>;
    readonly extensions: Set<string>;
    readonly requires: Array<string>;
    readonly transpilePlugins: boolean;
    readonly findBabelConfig: boolean;
    readonly ignore: PathPredicate;
    readonly stdio: boolean;
    readonly help: boolean;
    readonly dry: boolean;
    constructor(sourcePaths: Array<string>, plugins: Array<DeferredPlugin>, pluginOptions: Map<string, object>, extensions: Set<string>, requires: Array<string>, transpilePlugins: boolean, findBabelConfig: boolean, ignore: PathPredicate, stdio: boolean, help: boolean, dry: boolean);
    private _pluginCache?;
    getPlugins(): Array<Plugin>;
    loadRequires(): void;
    loadBabelTranspile(): void;
    getPlugin(name: string): Plugin | null;
    getBabelPlugins(): Array<BabelPlugin>;
    getBabelPlugin(name: string): BabelPlugin | null;
    static parse(args: Array<string>): ParseOptionsResult;
}
